@@ -3,7 +3,7 @@
 This package provides:
 
 - the :py:class:`~dagster_databricks.databricks_pyspark_step_launcher` resource, which
-    launches a Databricks job in which a solid can be run
+    launches a Databricks job in which an op can be run
 - the :py:class:`~dagster_databricks.DatabricksRunJobSolidDefinition`, which can be used
     to execute an arbitrary task in Databricks.
 """
@@ -17,7 +17,7 @@ from .databricks_pyspark_step_launcher import (
     databricks_pyspark_step_launcher,
 )
 from .resources import databricks_client
-from .solids import create_databricks_job_solid
+from .solids import create_databricks_job_op, create_databricks_job_solid
 from .types import (
     DATABRICKS_RUN_TERMINATED_STATES,
     DatabricksRunLifeCycleState,
@@ -29,6 +29,7 @@ check_dagster_package_version("dagster-databricks", __version__)
 
 __all__ = [
     "create_databricks_job_solid",
+    "create_databricks_job_op",
     "databricks_client",
     "DatabricksConfig",
     "DatabricksError",
